#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-GpgjwCtRRTmIJbneNoazSl
key:                  postgrest-10.1.0-GpgjwCtRRTmIJbneNoazSl
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  236a5737dd60730296aa759c17edec29
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-GpgjwCtRRTmIJbneNoazSl
depends:
    HTTP-4000.5.0-EkpNFMLOZzgASEja1ayH5T
    Ranged-sets-0.5.0-4V0uIYl3FiUGZHbhD6P6a7
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    auto-update-0.1.6-E5aLWRUFo6vLtvWCrvKB9n base-4.18.2.1
    base64-bytestring-1.2.1.0-LOSDeSQSndy1Y93aTSzs7h
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-9SCmNmyRT1LDc1Bi3mXj6e
    cassava-0.5.4.1-1IVaaBvprmSBn50VJDwGi5
    configurator-pg-0.2.11-9Ymfx3fIV09Km9E6yX2pS3 containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-CkgRKJSZ7UH2kTtQpcnCFp
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-61bVMpYOqZDKhSgjX0Mb3G
    hasql-dynamic-statements-0.3.1.2-2pd1ukvFsgIIq4Ue9snCOe
    hasql-notifications-0.2.1.0-8wcnvVYcyos1fN6oC5LKTH
    hasql-pool-0.8.0.3-Azo9uul5bOrBY3PiYVoyL
    hasql-transaction-1.0.1.3-AA99P35bzp7L22QqWujD5U
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    insert-ordered-containers-0.2.5.3-2znDmmr5kPXESZuRiXh3Uk
    interpolatedstring-perl6-1.0.2-CQPSfVjbrkHJWPQhV15tg2
    jose-0.11-4khCKjqq6Dg3YI1xQvPvUK lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    lens-aeson-1.2.3-3DLc89EhcgMIWsG7tCrhaz mtl-2.3.1
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    network-uri-2.6.4.2-1CJs0qlSGKv7cmTNxU9YR0
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    parsec-3.1.16.1 protolude-0.3.5-6SjXru4EqrW3IByg5dF3Yy
    regex-tdfa-1.3.2.6-7s6a3kMa1YssqXiRAnHSe
    retry-0.9.3.1-5vTIPhi2r08CzV6yedSxG1
    scientific-0.3.8.1-6O6hUkglHhJ388M1FqOkp1
    swagger2-2.9.1-Apk7dQ1jYNV3OyCpg1llMQ text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vault-0.3.2.0-CHFhjwtocqC1yyBgOAsYiw
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7
    wai-3.2.5-H9aJt8uWBWE1hbliPLgYgy
    wai-cors-0.2.7-8kVht3e0tDsLu8braDefNI
    wai-extra-3.1.18-6EEfXnNqkc69PST3as19rJ
    wai-logger-2.5.0-PCRv62koKW4jUqN43Vbuv
    warp-3.4.0-AcslzRJDkTTAZEWKdFG1IO

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

